@@ -1,12 +1,12 @@
 package File::Sticker::Database;
-$File::Sticker::Database::VERSION = '3.0008';
+$File::Sticker::Database::VERSION = '3.0101';
 =head1 NAME
 
 File::Sticker::Database - write info to database
 
 =head1 VERSION
 
-version 3.0008
+version 3.0101
 
 =head1 SYNOPSIS
 
@@ -504,6 +504,12 @@ sub query_by_tags ($$$) {
             like => 'GLOB',
             wildcard => '*',
         },
+        # I don't want these to be case-insensitive
+        # because tags could start with these words
+        and_regex        => qr/\&|AND/,
+        or_regex         => qr/\||OR/,
+        not_regex        => qr/NOT/,
+
         default_field => $default_field,
         default_op => '~',
         fields => \@pfields,
