@@ -1,12 +1,12 @@
 package File::Sticker::Writer;
-$File::Sticker::Writer::VERSION = '3.0008';
+$File::Sticker::Writer::VERSION = '3.0101';
 =head1 NAME
 
 File::Sticker::Writer - write and standardize meta-data from files
 
 =head1 VERSION
 
-version 3.0008
+version 3.0101
 
 =head1 SYNOPSIS
 
@@ -25,6 +25,7 @@ nomenclature.
 
 use common::sense;
 use File::LibMagic;
+use List::MoreUtils qw(uniq);
 
 =head1 DEBUGGING
 
@@ -432,12 +433,6 @@ sub add_multival_to_file {
     }
 
     # add new value(s) to existing taglike-values
-    my %th = ();
-
-    foreach my $t (@vals)
-    {
-        $th{$t} = 1;
-    }
     my @old_values = ();
     if (ref $old_vals eq 'ARRAY')
     {
@@ -447,12 +442,9 @@ sub add_multival_to_file {
     {
         @old_values = split(/,/, $old_vals);
     }
-    foreach my $t (@old_values)
-    {
-        $th{$t} = 1;
-    }
-    my @newvals = keys %th;
-    @newvals = sort @newvals;
+    my @newvals = @old_values;
+    push @newvals, @vals;
+    @newvals = uniq @newvals;
     my $newvals = join(',', @newvals);
 
     $self->replace_one_field(filename=>$filename,
@@ -494,8 +486,7 @@ sub delete_multival_from_file ($%) {
     }
 
     # remove value from existing values
-    my %th = ();
-
+    # preserving the existing order
     my @old_values = ();
     if (ref $old_vals eq 'ARRAY')
     {
@@ -505,15 +496,14 @@ sub delete_multival_from_file ($%) {
     {
         @old_values = split(/,/, $old_vals);
     }
+    my @newvals = ();
     foreach my $t (@old_values)
     {
         if (! exists $to_delete{$t})
         {
-            $th{$t} = 1;
+            push @newvals, $t;
         }
     }
-    my @newvals = keys %th;
-    @newvals = sort @newvals;
     my $newvals = join(',', @newvals);
 
     $self->replace_one_field(filename=>$filename,
